==========
Lib module
==========

Tools for the other modules.

.. warning::
    These tools have been designed primarily for internal use throughout the
    library and often work only in very specific situations (e.g.
    :func:`~nngt.lib.find_idx_nearest` works only on sorted arrays), so make
    sure you read their doc carefully before using them.


Content
=======

.. autosummary::

    nngt.lib.InvalidArgument
    nngt.lib.delta_distrib
    nngt.lib.find_idx_nearest
    nngt.lib.gaussian_distrib
    nngt.lib.is_integer
    nngt.lib.is_iterable
    nngt.lib.lin_correlated_distrib
    nngt.lib.log_correlated_distrib
    nngt.lib.lognormal_distrib
    nngt.lib.nonstring_container
    nngt.lib.uniform_distrib


Details
=======

.. automodule:: nngt.lib
